@@ -1,5 +1,5 @@
 /*
- * $Id: fifo_server.c,v 1.8 2006/01/09 18:51:57 miconda Exp $
+ * $Id: fifo_server.c,v 1.8.2.1 2006/11/22 19:18:11 bogdan_iancu Exp $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -703,7 +703,7 @@ int start_fifo_server()
 static int print_version_cmd( FILE *stream, char *response_file )
 {
 	if (response_file) {
-		fifo_reply(response_file, "200 ok\n" SERVER_HDR CRLF );
+		fifo_reply(response_file, "200 ok\n" SERVER_HDR );
 	} else {
 		LOG(L_ERR, "ERROR: no file for %s\n", "print_version_cmd" );
 	}
