@@ -1,5 +1,5 @@
 /**
- * $Id: items.c,v 1.32 2006/07/05 14:33:07 miconda Exp $
+ * $Id: items.c,v 1.32.2.3 2007/01/18 18:11:12 miconda Exp $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  * Copyright (C) 2005 Voice Sistem SRL
@@ -1299,11 +1299,13 @@ static int xl_get_branches(struct sip_msg *msg, xl_value_t *res, xl_param_t *par
 #define ITEM_PRINT_ALL	-2
 #define ITEM_PRINT_LAST	-1
 
-static int xl_get_header(struct sip_msg *msg, xl_value_t *res, xl_param_t *param,
-		int flags)
+static int xl_get_header(struct sip_msg *msg, xl_value_t *res,
+		xl_param_t *param, int flags)
 {
 	struct hdr_field *hf, *hf0;
 	char *p;
+	int lidx;
+	int found;
 	
 	if(msg==NULL || res==NULL)
 		return -1;
@@ -1315,7 +1317,13 @@ static int xl_get_header(struct sip_msg *msg, xl_value_t *res, xl_param_t *param
 	p = local_buf;
 
 	/* we need to be sure we have parsed all headers */
-	parse_headers(msg, HDR_EOH_F, 0);
+	if(parse_headers(msg, HDR_EOH_F, 0)<0)
+	{
+		LOG(L_ERR,"xl_get_header: error parsing headers\n");
+		return xl_get_null(msg, res, param, flags);
+	}
+	lidx = param->ind;
+	found = 0;
 	for (hf=msg->headers; hf; hf=hf->next)
 	{
 		if(param->val.s==NULL)
@@ -1330,7 +1338,7 @@ static int xl_get_header(struct sip_msg *msg, xl_value_t *res, xl_param_t *param
 		}
 		
 		hf0 = hf;
-		if(param->ind==ITEM_PRINT_ALL)
+		if(lidx==ITEM_PRINT_ALL)
 		{
 			if(p!=local_buf)
 			{
@@ -1355,28 +1363,35 @@ static int xl_get_header(struct sip_msg *msg, xl_value_t *res, xl_param_t *param
 			continue;
 		}
 		
-		if(param->ind==0)
+		if(lidx==0) {
+			found = 1;
 			goto done;
-		if(param->ind>0)
-			param->ind--;
+		}
+		if(lidx>0)
+			lidx--;
 	}
 	
 done:
 	res->flags = XL_VAL_STR;
-	if(param->ind==ITEM_PRINT_ALL)
+	if(lidx==ITEM_PRINT_ALL)
 	{
-		*p = 0;
-		res->rs.s = local_buf;
-		res->rs.len = p - local_buf;
-		return 0;
+		if(p != local_buf)
+		{
+			*p = 0;
+			res->rs.s = local_buf;
+			res->rs.len = p - local_buf;
+			return 0;
+		} else return xl_get_null(msg, res, param, flags);
 	}
 	
-	if(hf0==NULL || param->ind>0)
-		return xl_get_null(msg, res, param, flags);
-	res->rs.s = hf0->body.s;
-	res->rs.len = hf0->body.len;
-	trim(&res->rs);
-	return 0;
+	if(hf0!=NULL && (found==1 || lidx==ITEM_PRINT_LAST))
+	{
+		res->rs.s = hf0->body.s;
+		res->rs.len = hf0->body.len;
+		trim(&res->rs);
+		return 0;
+	}
+	return xl_get_null(msg, res, param, flags);
 }
 
 static int xl_get_avp(struct sip_msg *msg, xl_value_t *res, xl_param_t *param,
@@ -1387,6 +1402,7 @@ static int xl_get_avp(struct sip_msg *msg, xl_value_t *res, xl_param_t *param,
 	int_str avp_value;
 	struct usr_avp *avp;
 	char *p;
+	int lidx;
 	str s = {0, 0};
 	
 	if(msg==NULL || res==NULL)
@@ -1411,10 +1427,11 @@ static int xl_get_avp(struct sip_msg *msg, xl_value_t *res, xl_param_t *param,
 	if ((avp=search_first_avp(name_type, avp_name, &avp_value, 0))==0)
 		return xl_get_null(msg, res, param, flags);
 
+	lidx = param->ind;
+	
 	do {
 		/* todo: optimization for last avp !!! */
-		if(param->ind==0 || param->ind==ITEM_PRINT_ALL
-				|| param->ind==ITEM_PRINT_LAST)
+		if(lidx==0 || lidx==ITEM_PRINT_ALL || lidx==ITEM_PRINT_LAST)
 		{
 			if(avp->flags & AVP_VAL_STR)
 			{
@@ -1425,7 +1442,7 @@ static int xl_get_avp(struct sip_msg *msg, xl_value_t *res, xl_param_t *param,
 			}
 		}
 		
-		if(param->ind==ITEM_PRINT_ALL)
+		if(lidx==ITEM_PRINT_ALL)
 		{
 			if(p!=local_buf)
 			{
@@ -1450,11 +1467,11 @@ static int xl_get_avp(struct sip_msg *msg, xl_value_t *res, xl_param_t *param,
 			continue;
 		}
 		
-		if(param->ind==0)
+		if(lidx==0)
 			goto done;
-		if(param->ind>0)
-			param->ind--;
-		if(param->ind!=ITEM_PRINT_LAST)
+		if(lidx>0)
+			lidx--;
+		if(lidx!=ITEM_PRINT_LAST)
 		{
 			s.s   = NULL;
 			s.len = 0;
@@ -1463,7 +1480,7 @@ static int xl_get_avp(struct sip_msg *msg, xl_value_t *res, xl_param_t *param,
 	
 done:
 	res->flags = XL_VAL_STR;
-	if(param->ind==ITEM_PRINT_ALL)
+	if(lidx==ITEM_PRINT_ALL)
 	{
 		*p = 0;
 		res->rs.s = local_buf;
@@ -1477,7 +1494,7 @@ done:
 		}
 	}
 	
-	if(s.s==NULL || param->ind>0)
+	if(s.s==NULL || lidx>0)
 		return xl_get_empty(msg, res, param, flags);
 	res->rs.s = s.s;
 	res->rs.len = s.len;
@@ -1733,6 +1750,7 @@ char* xl_parse_vname(char *s, xl_spec_p e, int flags)
 			
 			/* dynamic name */
 			e->dp.itf = e0.itf;
+			e->flags |= e0.flags;
 			memcpy(&(e->p), &(e0.p), sizeof(xl_param_t));
 			p = xl_parse_index(p, &(e->dp.ind));
 			if(p==NULL)
@@ -1756,10 +1774,10 @@ char* xl_parse_vname(char *s, xl_spec_p e, int flags)
 		e->type = XL_HDR;
 		if(e->flags&XL_DPARAM)
 			DBG("xl_parse_vname: hdr double reference (%p/%p) (%.*s)"
-					" (%d) (%d/%d)\n", e->itf, e->dp.itf,
+					" (%d) (%d/0x%X)\n", e->itf, e->dp.itf,
 					(e->p.val.s)?e->p.val.len:0,
 					(e->p.val.s)?e->p.val.s:"",
-					e->p.val.len, e->p.ind, e->p.ind);
+					e->p.val.len, e->p.ind, e->flags);
 		goto done;
 	} else {
 		/* avp  - we expect s:, i:, letter or $ */
@@ -1779,6 +1797,7 @@ char* xl_parse_vname(char *s, xl_spec_p e, int flags)
 			{
 				/* dynamic name */
 				e->dp.itf = e0.itf;
+				e->flags |= e0.flags;
 				memcpy(&(e->p), &(e0.p), sizeof(xl_param_t));
 				p0 = p;
 				p = xl_parse_index(p, &(e->dp.ind));
@@ -1823,10 +1842,10 @@ char* xl_parse_vname(char *s, xl_spec_p e, int flags)
 		e->type = XL_AVP;
 		if(e->flags&XL_DPARAM)
 			DBG("xl_parse_vname: avp double reference (%p/%p) (%.*s)"
-					" (%d) (%d/%d)\n", e->itf, e->dp.itf,
+					" (%d) (%d/0x%X)\n", e->itf, e->dp.itf,
 					(e->p.val.s)?e->p.val.len:0,
 					(e->p.val.s)?e->p.val.s:"",
-					e->p.val.len, e->p.ind, e->p.ind);
+					e->p.val.len, e->p.ind, e->flags);
 		goto done;
 	}
 
@@ -2393,7 +2412,7 @@ int xl_get_spec_value(struct sip_msg* msg, xl_spec_p sp, xl_value_t *value,
 			return -1;
 		}
 		memset(&tv, 0, sizeof(xl_value_t));
-		(*sp->dp.itf)(msg, &tv, &(sp->p), flags);
+		(*sp->dp.itf)(msg, &tv, &(sp->p), (flags|(sp->flags&0xffff0000)));
 		if(tv.flags&XL_VAL_NULL)
 			return xl_get_null(msg, value, &(sp->p), flags);
 		memset(&tp, 0, sizeof(xl_param_t));
