@@ -1,5 +1,5 @@
 /*
- * $Id: avpops_impl.c,v 1.28 2006/07/10 10:17:39 miconda Exp $
+ * $Id: avpops_impl.c,v 1.28.2.2 2006/12/18 10:52:56 miconda Exp $
  *
  * Copyright (C) 2004 Voice Sistem SRL
  *
@@ -802,6 +802,8 @@ int ops_write_avp(struct sip_msg* msg, struct fis_param *src,
 			LOG(L_ERR,"ERROR:avpops:write_avp: cannot get value\n");
 			goto error;
 		}
+		if(xvalue.flags&XL_VAL_NULL)
+			return -1;
 		if(xvalue.flags&XL_TYPE_INT)
 		{
 			avp_val.n = xvalue.ri;
@@ -825,8 +827,11 @@ int ops_write_avp(struct sip_msg* msg, struct fis_param *src,
 		}
 		if (src->opd&AVPOPS_FLAG_DOMAIN0)
 			avp_val.s = uri.host;
-		else
+		else {
+			if(uri.user.len<=0)
+				return -1;
 			avp_val.s = uri.user;
+		}
 	}
 
 	/* get dst avp name */
@@ -1153,7 +1158,7 @@ int ops_check_avp( struct sip_msg* msg, struct fis_param* src,
 	int_str           avp_val;
 	int_str           check_val;
 	int               check_flags;
-	int               n;
+	int               n, rt;
 	int            flags;
 	xl_value_t     xvalue;
 	char           backup;
@@ -1261,10 +1266,11 @@ cycle2:
 	if (flags&AVP_VAL_STR)
 	{
 		/* string values to check */
-		DBG("DEBUG:avpops:check_avp: check <%.*s> against <%.*s> as str\n",
+		DBG("DEBUG:avpops:check_avp: check <%.*s> against <%.*s> as str /%d\n",
 			avp_val.s.len,avp_val.s.s,
 			(val->ops&AVPOPS_OP_RE)?6:check_val.s.len,
-			(val->ops&AVPOPS_OP_RE)?"REGEXP":check_val.s.s);
+			(val->ops&AVPOPS_OP_RE)?"REGEXP":check_val.s.s,
+			val->ops);
 		/* do check */
 		if (val->ops&AVPOPS_OP_EQ)
 		{
@@ -1293,7 +1299,10 @@ cycle2:
 			}
 		} else if (val->ops&AVPOPS_OP_LT) {
 			n = (avp_val.s.len>=check_val.s.len)?avp_val.s.len:check_val.s.len;
-			if (strncasecmp(avp_val.s.s,check_val.s.s,n)==-1)
+			rt = strncasecmp(avp_val.s.s,check_val.s.s,n);
+			if (rt<0)
+				return 1;
+			if(rt==0 && avp_val.s.len<check_val.s.len)
 				return 1;
 		} else if (val->ops&AVPOPS_OP_LE) {
 			n = (avp_val.s.len>=check_val.s.len)?avp_val.s.len:check_val.s.len;
@@ -1301,7 +1310,10 @@ cycle2:
 				return 1;
 		} else if (val->ops&AVPOPS_OP_GT) {
 			n = (avp_val.s.len>=check_val.s.len)?avp_val.s.len:check_val.s.len;
-			if (strncasecmp(avp_val.s.s,check_val.s.s,n)==1)
+			rt = strncasecmp(avp_val.s.s,check_val.s.s,n);
+			if (rt>0)
+				return 1;
+			if(rt==0 && avp_val.s.len>check_val.s.len)
 				return 1;
 		} else if (val->ops&AVPOPS_OP_GE) {
 			n = (avp_val.s.len>=check_val.s.len)?avp_val.s.len:check_val.s.len;
@@ -1331,8 +1343,8 @@ cycle2:
 		}
 	} else {
 		/* int values to check -> do check */
-		DBG("DEBUG:avpops:check_avp: check <%d> against <%d> as int\n",
-				avp_val.n, check_val.n);
+		DBG("DEBUG:avpops:check_avp: check <%d> against <%d> as int /%d\n",
+				avp_val.n, check_val.n, val->ops);
 		if (val->ops&AVPOPS_OP_EQ)
 		{
 			if ( avp_val.n==check_val.n)
