@@ -1,5 +1,5 @@
 /*
- * $Id: avpops_parse.c,v 1.8 2006/05/07 20:48:51 miconda Exp $
+ * $Id: avpops_parse.c,v 1.8.2.1 2006/09/19 15:03:15 miconda Exp $
  *
  * Copyright (C) 2004 Voice Sistem SRL
  *
@@ -666,7 +666,8 @@ struct fis_param* parse_op_value(char *s)
 		ops |= AVPOPS_OP_MUL;
 	} else if (strncasecmp(s,"div",3)==0) {
 		ops |= AVPOPS_OP_DIV;
-		ops |= AVPOPS_OP_FM;
+	} else if (strncasecmp(s,"mod",3)==0) {
+		ops |= AVPOPS_OP_MOD;
 	} else if (strncasecmp(s,"and",3)==0) {
 		ops |= AVPOPS_OP_BAND;
 	} else if (strncasecmp(s,"or",2)==0) {
