@@ -1,5 +1,5 @@
 /*
- * $Id: cpl.c,v 1.11 2006/03/01 12:02:49 bogdan_iancu Exp $
+ * $Id: cpl.c,v 1.11.2.2 2006/11/13 18:17:11 bogdan_iancu Exp $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -388,6 +388,9 @@ static int cpl_init(void)
 		strlower( &cpl_env.realm_prefix );
 	}
 
+	/* fix the flags */
+	cpl_env.nat_flag = 1<<cpl_env.nat_flag;
+
 	return 0;
 error:
 	return -1;
@@ -473,7 +476,7 @@ static inline int build_user_AOR(str *username, str *domain, str *uh, int sip)
 		/* do we need to strip realm prefix? */
 		if (cpl_env.realm_prefix.len && cpl_env.realm_prefix.len<domain->len){
 			for( i=cpl_env.realm_prefix.len-1 ; i>=0 ; i-- )
-				if ( cpl_env.realm_prefix.s[i]!=((domain->s[i])|(0x20)) )
+				if ( cpl_env.realm_prefix.s[i]!=tolower(domain->s[i]) )
 					break;
 			if (i==-1)
 				do_strip = 1;
@@ -499,13 +502,13 @@ static inline int build_user_AOR(str *username, str *domain, str *uh, int sip)
 		p += username->len;
 	} else {
 		for(i=0;i<username->len;i++)
-			*(p++) = (0x20)|(username->s[i]);
+			*(p++) = tolower(username->s[i]);
 	}
 	if (sip || cpl_env.use_domain) {
 		*(p++) = '@';
 		/* host part in lower cases */
 		for( i=do_strip*cpl_env.realm_prefix.len ; i< domain->len ; i++ )
-			*(p++) = (0x20)|(domain->s[i]);
+			*(p++) = tolower(domain->s[i]);
 	}
 	*(p++) = 0;
 
