@@ -1,5 +1,5 @@
 /**
- * $Id: pdt.c,v 1.8 2006/07/03 15:26:17 miconda Exp $
+ * $Id: pdt.c,v 1.8.2.1 2006/10/29 20:25:51 miconda Exp $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -350,15 +350,22 @@ static int prefix2domain(struct sip_msg* msg, int mode)
 	if (msg->parsed_uri.user.len<=0)
 	{
 		DBG("PDT:prefix2domain: user part of the message is empty\n");
-		return 1;
+		return -1;
 	}
 	
-	if(prefix.len>0 && prefix.len < msg->parsed_uri.user.len
-			&& strncasecmp(prefix.s, msg->parsed_uri.user.s, prefix.len)!=0)
+	if(prefix.len>0)
 	{
-		DBG("PDT:prefix2domain: PSTN prefix did not matched\n");
-		return 1;
+		if (msg->parsed_uri.user.len<=prefix.len)
+		{
+			DBG("PDT:prefix2domain: user part is less than prefix\n");
+			return -1;
+		}
+		if(strncasecmp(prefix.s, msg->parsed_uri.user.s, prefix.len)!=0)
+		{
+			DBG("PDT:prefix2domain: PSTN prefix did not matched\n");
+			return -1;
 			
+		}
 	}
 
 	p.s   = msg->parsed_uri.user.s + prefix.len;
@@ -373,8 +380,9 @@ static int prefix2domain(struct sip_msg* msg, int mode)
 		last_sync = crt_time;
 		if(pdt_sync_cache())
 		{
+			/* keep reporting but continue */
 			LOG(L_ERR, "PDT:prefix2domain: cannot update the cache\n");
-			return -1;
+			/* return -1; */
 		}
 	}
 
