@@ -1,5 +1,5 @@
 /*
- * $Id: dbase.c,v 1.4 2005/09/13 18:05:03 klaus_darilion Exp $
+ * $Id: dbase.c,v 1.4.4.2 2007/01/17 12:35:40 klaus_darilion Exp $
  *
  * POSTGRES module, portions of this code were templated using
  * the mysql module, thus it's similarity.
@@ -595,7 +595,7 @@ static int print_columns(char* _b, int _l, db_key_t* _c, int _n)
 /*
  * Print list of values separated by comma
  */
-static int print_values(char* _b, int _l, db_val_t* _v, int _n)
+static int print_values(db_con_t* _con, char* _b, int _l, db_val_t* _v, int _n)
 {
 	int i, res = 0, l;
 
@@ -603,7 +603,7 @@ static int print_values(char* _b, int _l, db_val_t* _v, int _n)
 		l = _l - res;
 /*		LOG(L_ERR, "%d sizes l = _l - res %d = %d - %d\n", i, l,_l,res);
 */
-		if (val2str(_v + i, _b + res, &l) < 0) {
+		if (val2str(_con, _v + i, _b + res, &l) < 0) {
 			LOG(L_ERR,
 			 "print_values(): Error converting value to string\n");
 			return 0;
@@ -621,7 +621,7 @@ static int print_values(char* _b, int _l, db_val_t* _v, int _n)
 /*
  * Print where clause of SQL statement
  */
-static int print_where(char* _b, int _l, db_key_t* _k,
+static int print_where(db_con_t* _con, char* _b, int _l, db_key_t* _k,
 	db_op_t* _o, db_val_t* _v, int _n)
 {
 	int i;
@@ -635,7 +635,7 @@ static int print_where(char* _b, int _l, db_key_t* _k,
 			res += snprintf(_b + res, _l - res, "%s=", _k[i]);
 		}
 		l = _l - res;
-		val2str(&(_v[i]), _b + res, &l);
+		val2str(_con, &(_v[i]), _b + res, &l);
 		res += l;
 		if (i != (_n - 1)) {
 			res += snprintf(_b + res, _l - res, " AND ");
@@ -648,7 +648,7 @@ static int print_where(char* _b, int _l, db_key_t* _k,
 /*
  * Print set clause of update SQL statement
  */
-static int print_set(char* _b, int _l, db_key_t* _k,
+static int print_set(db_con_t* _con, char* _b, int _l, db_key_t* _k,
 	db_val_t* _v, int _n)
 {
 	int i;
@@ -657,7 +657,7 @@ static int print_set(char* _b, int _l, db_key_t* _k,
 	for(i = 0; i < _n; i++) {
 		res += snprintf(_b + res, _l - res, "%s=", _k[i]);
 		l = _l - res;
-		val2str(&(_v[i]), _b + res, &l);
+		val2str(_con, &(_v[i]), _b + res, &l);
 		res += l;
 		if (i != (_n - 1)) {
 			if ((_l - res) >= 1) {
@@ -696,7 +696,7 @@ int db_query(db_con_t* _h, db_key_t* _k, db_op_t* _op,
 	}
 	if (_n) {
 		off += snprintf(sql_buf + off, SQL_BUF_LEN - off, "where ");
-		off += print_where(sql_buf + off, SQL_BUF_LEN - off,
+		off += print_where(_h, sql_buf + off, SQL_BUF_LEN - off,
 			_k, _op, _v, _n);
 	}
 	if (_o) {
@@ -722,7 +722,7 @@ int db_query(db_con_t* _h, db_key_t* _k, db_op_t* _op,
  */
 int db_raw_query(db_con_t* _h, char* _s, db_res_t** _r)
 {
-	int rv;
+	int rv=0;
 
 	if(begin_transaction(_h, sql_buf)) return(-1);
 	if (submit_query(_h, _s) < 0) {
@@ -730,7 +730,8 @@ int db_raw_query(db_con_t* _h, char* _s, db_res_t** _r)
 		rollback_transaction(_h);
 		return -2;
 	}
-	rv = get_result(_h, _r);
+	if(_r)
+		rv = get_result(_h, _r);
 	free_query(_h);
 	commit_transaction(_h);
 	return(rv);
@@ -774,7 +775,7 @@ int db_insert(db_con_t* _h, db_key_t* _k, db_val_t* _v, int _n)
 	off = snprintf(sql_buf, SQL_BUF_LEN, "insert into %s (", CON_TABLE(_h));
 	off += print_columns(sql_buf + off, SQL_BUF_LEN - off, _k, _n);
 	off += snprintf(sql_buf + off, SQL_BUF_LEN - off, ") values (");
-	off += print_values(sql_buf + off, SQL_BUF_LEN - off, _v, _n);
+	off += print_values(_h, sql_buf + off, SQL_BUF_LEN - off, _v, _n);
 	*(sql_buf + off++) = ')';
 	*(sql_buf + off) = '\0';
 
@@ -804,7 +805,7 @@ int db_delete(db_con_t* _h, db_key_t* _k, db_op_t* _o, db_val_t* _v, int _n)
 	off = snprintf(sql_buf, SQL_BUF_LEN, "delete from %s", CON_TABLE(_h));
 	if (_n) {
 		off += snprintf(sql_buf + off, SQL_BUF_LEN - off, " where ");
-		off += print_where(sql_buf + off, SQL_BUF_LEN - off, _k,
+		off += print_where(_h, sql_buf + off, SQL_BUF_LEN - off, _k,
 			_o, _v, _n);
 	}
 	if(begin_transaction(_h, sql_buf)) return(-1);
@@ -835,10 +836,10 @@ int db_update(db_con_t* _h, db_key_t* _k, db_op_t* _o, db_val_t* _v,
 {
 	int off;
 	off = snprintf(sql_buf, SQL_BUF_LEN, "update %s set ", CON_TABLE(_h));
-	off += print_set(sql_buf + off, SQL_BUF_LEN - off, _uk, _uv, _un);
+	off += print_set(_h, sql_buf + off, SQL_BUF_LEN - off, _uk, _uv, _un);
 	if (_n) {
 		off += snprintf(sql_buf + off, SQL_BUF_LEN - off, " where ");
-		off += print_where(sql_buf + off, SQL_BUF_LEN - off, _k,
+		off += print_where(_h, sql_buf + off, SQL_BUF_LEN - off, _k,
 			_o, _v, _n);
 		*(sql_buf + off) = '\0';
 	}
