@@ -1,5 +1,5 @@
 /*
- * $Id: t_lookup.c,v 1.15 2006/07/05 11:47:38 bogdan_iancu Exp $
+ * $Id: t_lookup.c,v 1.15.2.2 2007/01/12 10:03:11 bogdan_iancu Exp $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -316,7 +316,8 @@ static int matching_3261( struct sip_msg *p_msg, struct cell **trans,
 		 */
 
 		/* dialog matching needs to be applied for ACK/200s */
-		if (is_ack && p_cell->uas.status<300 && e2e_ack_trans==0) {
+		if (is_ack && e2e_ack_trans==0 &&
+		p_cell->uas.status>=200 && p_cell->uas.status<300) {
 			/* make sure we have parsed all things we need for dialog
 			 * matching */
 			if (!dlg_parsed) {
@@ -329,7 +330,7 @@ static int matching_3261( struct sip_msg *p_msg, struct cell **trans,
 			ret=ack_matching(p_cell /* t w/invite */, p_msg /* ack */);
 			if (ret>0) {
 				e2e_ack_trans=p_cell;
-				break;
+				continue;
 			}
 			/* this ACK is neither local "negative" one, nor a proxied
 			 * end-2-end one, nor an end-2-end one for a UAS transaction
