@@ -1,5 +1,5 @@
 /*
- * $Id: t_reply.c,v 1.28 2006/06/27 14:58:33 bogdan_iancu Exp $
+ * $Id: t_reply.c,v 1.28.2.2 2006/09/21 20:09:18 bogdan_iancu Exp $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -306,6 +306,7 @@ static int _reply_light( struct cell *trans, char* buf, unsigned int len,
 	struct retr_buf *rb;
 	unsigned int buf_len;
 	branch_bm_t cancel_bitmap;
+	str cb_s;
 
 	if (!buf)
 	{
@@ -362,7 +363,9 @@ static int _reply_light( struct cell *trans, char* buf, unsigned int len,
 			}
 		} else {
 			if ( has_tran_tmcbs(trans, TMCB_RESPONSE_OUT) ) {
-				set_extra_tmcb_params( &rb->buffer, &rb->dst);
+				cb_s.s = buf;
+				cb_s.len = len;
+				set_extra_tmcb_params( &cb_s, &rb->dst);
 				run_trans_callbacks( TMCB_RESPONSE_OUT, trans,
 					trans->uas.request, FAKED_REPLY, code);
 			}
@@ -733,11 +736,13 @@ static enum rps t_should_relay_response( struct cell *Trans , int new_code,
 			*should_store=1;
 			*should_relay=-1;
 			picked_branch=-1;
+			Trans->uac[branch].reply = 0;
 			return RPS_STORE;
 		}
 		if (picked_branch==-1) {
 			LOG(L_CRIT, "ERROR:tm:t_should_relay_response: pick_branch failed "
 				"(lowest==-1) for code %d\n",new_code);
+			Trans->uac[branch].reply = 0;
 			goto discard;
 		}
 
@@ -949,6 +954,7 @@ enum rps relay_reply( struct cell *t, struct sip_msg *p_msg, int branch,
 	enum rps reply_status;
 	/* retransmission structure of outbound reply and request */
 	struct retr_buf *uas_rb;
+	str cb_s;
 
 	/* keep compiler warnings about use of uninit vars silent */
 	res_len=0;
@@ -1071,7 +1077,9 @@ enum rps relay_reply( struct cell *t, struct sip_msg *p_msg, int branch,
 		DBG("DEBUG:tm:relay_reply: sent buf=%p: %.9s..., shmem=%p: %.9s\n", 
 			buf, buf, uas_rb->buffer.s, uas_rb->buffer.s );
 		if (!totag_retr && has_tran_tmcbs(t, TMCB_RESPONSE_OUT) ) {
-			set_extra_tmcb_params( &uas_rb->buffer, &uas_rb->dst);
+			cb_s.s = buf;
+			cb_s.len = res_len;
+			set_extra_tmcb_params( &cb_s, &uas_rb->dst);
 			run_trans_callbacks( TMCB_RESPONSE_OUT, t, t->uas.request,
 				relayed_msg, relayed_code);
 		}
