@@ -1,5 +1,5 @@
 /* 
- * $Id: udomain.c,v 1.18 2006/07/04 13:52:19 bogdan_iancu Exp $ 
+ * $Id: udomain.c,v 1.18.2.2 2006/11/24 18:54:21 bogdan_iancu Exp $ 
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -37,6 +37,7 @@
 #include "../../db/db.h"
 #include "../../socket_info.h"
 #include "../../ut.h"
+#include "../../hash_func.h"
 #include "ul_mod.h"            /* usrloc module parameters */
 #include "utime.h"
 #include "notify.h"
@@ -44,7 +45,6 @@
 
 /*
  * Hash function
- */
 static inline int hash_func(udomain_t* _d, unsigned char* _s, int _l)
 {
 	int res = 0, i;
@@ -55,6 +55,7 @@ static inline int hash_func(udomain_t* _d, unsigned char* _s, int _l)
 	
 	return res % _d->size;
 }
+*/
 
 
 /*
@@ -315,7 +316,7 @@ static inline ucontact_info_t* dbrow2info( db_val_t *vals, str *contact)
 	ci.flags1  = VAL_BITMAP(vals+5);
 
 	ua.s  = (char*)VAL_STRING(vals+6);
-	if (VAL_NULL(vals+6) || !ua.s || !ua.s[0]==0) {
+	if (VAL_NULL(vals+6) || !ua.s || !ua.s[0]) {
 		ua.s = 0;
 		ua.len = 0;
 	} else {
@@ -654,7 +655,7 @@ int mem_insert_urecord(udomain_t* _d, str* _aor, struct urecord** _r)
 		return -1;
 	}
 
-	sl = hash_func(_d, (unsigned char*)_aor->s, _aor->len);
+	sl = core_hash(_aor, 0, _d->size);
 	slot_add(&_d->table[sl], *_r);
 	udomain_add(_d, *_r);
 	update_stat( _d->users, 1);
@@ -753,7 +754,7 @@ int get_urecord(udomain_t* _d, str* _aor, struct urecord** _r)
 
 	if (db_mode!=DB_ONLY) {
 		/* search in cache */
-		sl = hash_func(_d, (unsigned char*)_aor->s, _aor->len);
+		sl = core_hash(_aor, 0, _d->size);
 		r = _d->table[sl].first;
 
 		for(i = 0; i < _d->table[sl].n; i++) {
