@@ -1,4 +1,4 @@
-/* $Id: resolve.c,v 1.11 2006/06/26 08:42:26 bogdan_iancu Exp $
+/* $Id: resolve.c,v 1.11.2.2 2006/11/29 18:08:29 bogdan_iancu Exp $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  * Copyright (C) 2005-2006 Voice Sistem S.R.L.
@@ -300,7 +300,10 @@ error:
 void free_rdata_list(struct rdata* head)
 {
 	struct rdata* l;
-	for(l=head; l; l=l->next){
+	struct rdata* next_l;
+
+	for( l=head; l ; l=next_l) {
+		next_l = l->next;
 		/* free the parsed rdata*/
 		if (l->rdata) local_free(l->rdata);
 		local_free(l);
@@ -474,6 +477,8 @@ struct rdata* get_record(char* name, int type)
 	return head;
 error_boundary:
 		LOG(L_ERR, "ERROR: get_record: end of query buff reached\n");
+		if(head)
+			free_rdata_list(head);
 		return 0;
 error_parse:
 		LOG(L_ERR, "ERROR: get_record: rdata parse error \n");
